RegisterValueType

Type Alias RegisterValueType 

pub type RegisterValueType = BNRegisterValueType;

Aliased Type

#[repr(u32)]
pub enum RegisterValueType {
Show 19 variants UndeterminedValue = 0, EntryValue = 1, ConstantValue = 2, ConstantPointerValue = 3, ExternalPointerValue = 4, StackFrameOffset = 5, ReturnAddressValue = 6, ImportedAddressValue = 7, ResultPointerValue = 8, ParameterPointerValue = 9, SignedRangeValue = 10, UnsignedRangeValue = 11, LookupTableValue = 12, InSetOfValues = 13, NotInSetOfValues = 14, ConstantDataValue = 32_768, ConstantDataZeroExtendValue = 32_769, ConstantDataSignExtendValue = 32_770, ConstantDataAggregateValue = 32_771,
}

Variants



UndeterminedValue = 0



EntryValue = 1



ConstantValue = 2



ConstantPointerValue = 3



ExternalPointerValue = 4



StackFrameOffset = 5



ReturnAddressValue = 6



ImportedAddressValue = 7



ResultPointerValue = 8



ParameterPointerValue = 9



SignedRangeValue = 10

The following are only valid in BNPossibleValueSet



UnsignedRangeValue = 11

The following are only valid in BNPossibleValueSet



LookupTableValue = 12

The following are only valid in BNPossibleValueSet



InSetOfValues = 13

The following are only valid in BNPossibleValueSet



NotInSetOfValues = 14

The following are only valid in BNPossibleValueSet



ConstantDataValue = 32_768

The following support constant data and values larger than 8 bytes



ConstantDataZeroExtendValue = 32_769

The following support constant data and values larger than 8 bytes



ConstantDataSignExtendValue = 32_770

The following support constant data and values larger than 8 bytes



ConstantDataAggregateValue = 32_771

The following support constant data and values larger than 8 bytes